Top level API (:mod:`cmomy`)
============================

.. automodule:: cmomy
   :no-members:
   :no-inherited-members:
   :no-special-members:




Central Moments wrapper classes
-------------------------------

.. autosummary::
   :toctree: generated/

   CentralMoments
   xCentralMoments

Concatenation
-------------

.. autosummary::

   ~cmomy.convert.concat



Reduction routines available at top level (from :mod:`cmomy.reduction`)
-----------------------------------------------------------------------

.. autosummary::

   ~cmomy.reduction.reduce_data
   ~cmomy.reduction.reduce_data_grouped
   ~cmomy.reduction.reduce_data_indexed

Resampling routines available at top level (from :mod:`cmomy.resample`)
-----------------------------------------------------------------------

.. autosummary::

   ~cmomy.resample.resample_data
   ~cmomy.resample.resample_vals
   ~cmomy.resample.random_freq
   ~cmomy.resample.random_indices
   ~cmomy.resample.randsamp_freq
   ~cmomy.resample.indices_to_freq


Pre-loaded modules
------------------

.. autosummary::

   ~cmomy.random
   ~cmomy.reduction
   ~cmomy.resample
   ~cmomy.convert
